#include <string>
#include <list>

#include "global.h"
#include "Info.hpp"

namespace cURLpp
{
	
template< >
void
cURLpp::InfoTypeConverter< std::string >::get(cURLpp::Easy &handle, 
				              CURLINFO info,
				              std::string &value)
{
  char *tmp;
  InfoGetter::get(handle, info, tmp);
  value = tmp;
}

template< >
void 
cURLpp::InfoTypeConverter< std::list< std::string > >::get(cURLpp::Easy &,
			                                   CURLINFO ,
						           std::list< std::string > &)
{
  
}


template< >
void 
cURLpp::InfoTypeConverter< long >::get(cURLpp::Easy &,
			                                   CURLINFO ,
						           long &)
{
  
}

}; /*namespace cURLpp */
